
#ifndef _C14_ev694_
#define _C14_ev694_

#ifdef __cplusplus
extern "C" {
#endif

extern void F1372_13285(EIF_REFERENCE);
extern void EIF_Minit694(void);
extern void F1365_13200(EIF_REFERENCE);
extern void F1306_12429(EIF_REFERENCE, EIF_POINTER);

#ifdef __cplusplus
}
#endif

#endif
